pub struct Index {
pub name: Option<String>,
pub columns: Vec<String>,
}Expand description
An index of a Model i.e. the table’s index over one or more of its columns
Indexes are not declared on a Model directly. They are spread over its Fields using Annotation::Index and gathered by Model::indexes.
Fields
name: Option<String>The name the index was declared under i.e. IndexValue::name
It is None for an index which was declared without an IndexValue.
Such an index always spans exactly one column.
columns: Vec<String>The columns the index spans, in the order they should be indexed in
Implementations